Paginator — Django Stories 1.0 documentation

Django Stories 1.0 documentation

# Paginator

- Table of Contents
- index
  modules
  next
  previous

# Paginator

class `stories.paragraph_paginator.` `ParagraphPaginator`(text, per_page, orphans=0, allow_empty_first_page=True)

  A paginator that takes HTML-formatted text, and returns lists of paragraphs. This allows articles to keep paragraphs together. Working with some custom filters, it also allows for dynamically adding attributes to paragraph tags